package com.srs.routine.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.routine.domain.RtStuAtSchool;

/**
 * 测试Service接口
 *
 * @author srs
 * @date 2024-05-27
 */
public interface IRtStuAtSchoolService extends IService<RtStuAtSchool> {
    /**
     * 查询测试
     *
     * @param id 测试主键
     * @return 测试
     */
    public RtStuAtSchool selectRtStuAtSchoolById(Integer id);

    public RtStuAtSchool selectRtStuAtSchoolByStudentId(String studentId);

    /**
     * 查询测试列表
     *
     * @param rtStuAtSchool 测试
     * @return 测试集合
     */
    List<RtStuAtSchool> selectRtStuAtSchoolList(RtStuAtSchool rtStuAtSchool);

    /**
     * 新增测试
     *
     * @param rtStuAtSchool 测试
     * @return 结果
     */
    int insertRtStuAtSchool(RtStuAtSchool rtStuAtSchool);

    /**
     * 修改测试
     *
     * @param rtStuAtSchool 测试
     * @return 结果
     */
    int updateRtStuAtSchool(RtStuAtSchool rtStuAtSchool);

    /**
     * 批量删除测试
     *
     * @param ids 需要删除的测试主键集合
     * @return 结果
     */
    int deleteRtStuAtSchoolByIds(Integer[] ids);

    /**
     * 删除测试信息
     *
     * @param id 测试主键
     * @return 结果
     */
    int deleteRtStuAtSchoolById(Integer id);
}
